@@ -12,9 +12,9 @@ use IPC::System::Options 'system', 'readpipe', -log=>1;
 our $AUTHORITY = 'cpan:PERLANCAR'; # AUTHORITY
 our $DATE = '2022-12-08'; # DATE
 our $DIST = 'Clipboard-Any'; # DIST
-our $VERSION = '0.006'; # VERSION
+our $VERSION = '0.007'; # VERSION
 
-my $known_clipboard_managers = [qw/klipper parcellite/];
+my $known_clipboard_managers = [qw/klipper parcellite clipit/];
 my $sch_clipboard_manager = ['str', in=>$known_clipboard_managers];
 our %argspecopt_clipboard_manager = (
     clipboard_manager => {
@@ -367,7 +367,7 @@ Clipboard::Any - Common interface to clipboard manager functions
 
 =head1 VERSION
 
-This document describes version 0.006 of Clipboard::Any (from Perl distribution Clipboard-Any), released on 2022-12-08.
+This document describes version 0.007 of Clipboard::Any (from Perl distribution Clipboard-Any), released on 2022-12-08.
 
 =head1 DESCRIPTION
 
